@@ -7,7 +7,7 @@ from netbox.api.fields import ContentTypeField
 from netbox.api.serializers import NetBoxModelSerializer
 from netbox.constants import NESTED_SERIALIZER_PREFIX
 from netbox_storage.api.nested_serializers import NestedFilesystemSerializer, NestedDriveSerializer, \
-    NestedMountedVolumeSerializer, NestedDeviceSerializer, NestedVolumeGroupSerializer
+    NestedMountedVolumeSerializer, NestedLinuxDeviceSerializer, NestedVolumeGroupSerializer
 from netbox_storage.models import Drive, Filesystem, Partition, MountedVolume, StorageConfigurationDrive, \
     LinuxDevice, TemplateConfigurationDrive, PhysicalVolume, VolumeGroup, LogicalVolume
 from utilities.api import get_serializer_for_model
@@ -50,7 +50,7 @@ class DriveSerializer(NetBoxModelSerializer):
 class PartitionSerializer(serializers.ModelSerializer):
     url = serializers.HyperlinkedIdentityField(view_name='plugins-api:netbox_storage-api:partition-detail')
     drive = NestedDriveSerializer(required=False, allow_null=True)
-    device = NestedDeviceSerializer(required=False, allow_null=True)
+    device = NestedLinuxDeviceSerializer(required=False, allow_null=True)
 
     class Meta:
         model = Partition
@@ -112,7 +112,7 @@ class LinuxDeviceSerializer(serializers.ModelSerializer):
 
 
 class PhysicalVolumeSerializer(serializers.ModelSerializer):
-    linux_device = NestedDeviceSerializer(required=False, allow_null=True)
+    linux_device = NestedLinuxDeviceSerializer(required=False, allow_null=True)
     vg = NestedVolumeGroupSerializer(required=False, allow_null=True)
 
     class Meta:
@@ -143,7 +143,7 @@ class VolumeGroupSerializer(serializers.ModelSerializer):
 
 
 class LogicalVolumeSerializer(serializers.ModelSerializer):
-    device = NestedDeviceSerializer(required=False, allow_null=True)
+    device = NestedLinuxDeviceSerializer(required=False, allow_null=True)
     vg = NestedVolumeGroupSerializer(required=False, allow_null=True)
 
     class Meta:
