@@ -6,7 +6,7 @@ from netbox_storage.models import PhysicalVolume
 class PhysicalVolumeFilter(NetBoxModelFilterSet):
     class Meta:
         model = PhysicalVolume
-        fields = ["device", "vg", "description"]
+        fields = ["linux_device", "vg", "description"]
 
     def search(self, queryset, name, value):
         """Perform the filtered search."""
