@@ -146,10 +146,12 @@ class LinuxDevice(NetBoxModel):
         ct_field='content_type',
         fk_field='object_id'
     )
-    drives = GenericRelation(Drive, related_query_name='linux_device_drives')
 
     clone_fields = ['device', 'type', 'size', 'content_type', 'object_id']
 
+    class Meta:
+        ordering = ['device', 'type', 'size', 'content_type', 'object_id']
+
     def __str__(self):
         return f'{self.device} ({self.type})'
 
@@ -270,10 +272,10 @@ class VolumeGroup(NetBoxModel):
 
 
 class PhysicalVolume(NetBoxModel):
-    device = models.ForeignKey(
+    linux_device = models.ForeignKey(
         LinuxDevice,
         on_delete=models.CASCADE,
-        related_name='device_physicalvolume',
+        related_name='linux_device_physicalvolume',
     )
     vg = models.ForeignKey(
         VolumeGroup,
@@ -286,7 +288,7 @@ class PhysicalVolume(NetBoxModel):
     )
 
     clone_fields = [
-        'device',
+        'linux_device',
         'vg',
         'description',
     ]
@@ -295,10 +297,10 @@ class PhysicalVolume(NetBoxModel):
         return reverse('plugins:netbox_storage:physicalvolume', kwargs={'pk': self.pk})
 
     def __str__(self):
-        return f'{self.device}'
+        return f'{self.linux_device}'
 
     class Meta:
-        ordering = ('device', 'description')
+        ordering = ('linux_device', 'description')
 
 
 class LogicalVolume(NetBoxModel):
