@@ -15,12 +15,12 @@ class PhysicalVolumeTable(NetBoxTable):
         model = PhysicalVolume
         fields = (
             "pk",
-            "device",
+            "linux_device",
             "vg",
             "description",
         )
         default_columns = (
-            "device",
+            "linux_device",
             "vg",
             "description",
         )
