@@ -6,7 +6,7 @@ from netbox_storage.models import TemplateConfigurationDrive, Partition, Logical
 
 
 class LVMAddTemplateView(generic.ObjectEditView):
-    queryset = MountedVolume.objects.all()
+    queryset = LogicalVolume.objects.all()
     form = LVMTemplateForm
     default_return_url = "plugins:netbox_storage:drive_list"
 
